# pySLiM

`pyslim` is a python module to allow reading and writing of SLiM-produced tree sequences
as a thin interface to [tskit](https://tskit.readthedocs.io/en/stable).
Please see [our documentation](https://pyslim.readthedocs.io/en/stable/) for more information.
(That link is to documentation for the [last release](https://pyslim.readthedocs.io/en/stable/) release;
instead, [the latest](https://pyslim.readthedocs.io/en/latest/) documentation
may have additional examples, but may also describe features you need to install from github to get.)

## Installation

To install `pyslim`, do
```
pip install pyslim
```
or read the documentation for how to [install from source](https://pyslim.readthedocs.io/en/stable/development.html#sec-development).

<a href='https://pyslim.readthedocs.io/en/latest/?badge=latest'>
    <img src='https://readthedocs.org/projects/pyslim/badge/?version=latest' alt='Documentation Status' />
</a>
